import yt
import matplotlib.pyplot as plt
import numpy as np

fileslist = ["270e3_binary_TEST.out.000001", "500e3_binary_TEST.out.000001"]

for filename in fileslist: 

    ds = yt.load(filename)
    ad = ds.all_data()

    coord = ad[('Gas', 'Coordinates')]
    he4 = ad[('Gas', 'he4')]

    # find out where yt starts to misread helium-4
    # mass fraction values
    #
    #for index,frac in enumerate(he4):
    #    if frac == 0.:
    #        first_zero = index
    #        print 'first zero: ',first_zero
    #        break
    #
    # seems that yt stops reading in the correct values
    # for the helium-4 mass fraction at the particle 
    # indexed by first_zero below
    first_zero = 262144


    # load values of he4 directly from the
    # {filename}.he4 file and remove the 
    # first line that contains the number 
    # of particles
    he4_from_file = np.loadtxt(filename + '.he4')
    nParticles = he4_from_file[0]
    he4_from_file = he4_from_file[1:]

    # arrays of positions of particles with
    # helium-4 mass fraction values less 
    # than and equal to the correct value of
    # 0.04
    low_he4 = coord[he4 < 0.04]
    hi_he4 = coord[he4 == 0.04]

    # array to plot entire he4 array
    temp_array = np.arange(nParticles)

    fig = plt.figure(figsize=(12,6))
    ax1 = fig.add_subplot(1,2,1)
    ax2 = fig.add_subplot(1,2,2)

    ax1.scatter(low_he4[:,0], low_he4[:,1], color='blue', label='Low', alpha=0.5)
    ax1.scatter(hi_he4[:,0], hi_he4[:,1], color='red', label='Hi', alpha=0.5)
    ax1.set_xlim(xmin=-1.5e9, xmax=1.5e9)
    ax1.set_ylim(ymin=-1.5e9, ymax=1.5e9)
    ax1.set_xlabel('x [cm]')
    ax1.set_ylabel('y [cm]')
    ax1.legend(loc='upper left')

    ax2.scatter(temp_array, he4, color='blue', label='Loaded by yt', s=12)
    ax2.scatter(temp_array, he4_from_file, color='red', label='.he4 file values', alpha=0.25, s=4)
    ax2.axvline(x=first_zero, color='gray', linestyle='--')
    ax2.set_xlim(xmin=0)
    ax2.set_ylim(ymin=-0.005, ymax=0.05)
    ax2.set_xlabel('Particle Number')
    ax2.set_ylabel('Helium-4 fraction')
    if len(he4) > first_zero:
        ax2.annotate('Particle\nindex\n'+str(first_zero), xy=(first_zero, 0.02), xytext=(first_zero - 150000, 0.03),
                            arrowprops=dict(facecolor='black', shrink=0.05))
    ax2.legend(loc='upper left')

    plt.savefig(filename + '.png')
    plt.clf()
